summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorDave Davenport <qball@gmpclient.org>2017-09-07 13:46:09 +0200
committerDave Davenport <qball@gmpclient.org>2017-09-07 13:46:09 +0200
commitacfc07a63e056bff1338a3430acc3ea93bd9ecc6 (patch)
treecebdfb095949292decfa14644a0200c465df30f7 /include
parent72f050e2fc2f7fdc2565100b6e1c0ddc10910c53 (diff)
Fix Inherit keyword
Diffstat (limited to 'include')
-rw-r--r--include/widgets/box.h2
-rw-r--r--include/widgets/container.h3
-rw-r--r--include/widgets/listview.h2
-rw-r--r--include/widgets/scrollbar.h3
-rw-r--r--include/widgets/textbox.h2
-rw-r--r--include/widgets/widget-internal.h5
6 files changed, 10 insertions, 7 deletions
diff --git a/include/widgets/box.h b/include/widgets/box.h
index 21724b1a..0bc34f8c 100644
--- a/include/widgets/box.h
+++ b/include/widgets/box.h
@@ -53,7 +53,7 @@ typedef struct _box box;
*
* @returns a newly created box, free with #widget_free
*/
-box * box_create ( const char *name, RofiOrientation type );
+box * box_create ( widget *parent, const char *name, RofiOrientation type );
/**
* @param box Handle to the box widget.
diff --git a/include/widgets/container.h b/include/widgets/container.h
index 60c0b258..e0233562 100644
--- a/include/widgets/container.h
+++ b/include/widgets/container.h
@@ -44,11 +44,12 @@
typedef struct _window container;
/**
+ * @parem parent The widget's parent
* @param name The name of the widget.
*
* @returns a newly created container, free with #widget_free
*/
-container * container_create ( const char *name );
+container * container_create ( widget *parent, const char *name );
/**
* @param container Handle to the container widget.
diff --git a/include/widgets/listview.h b/include/widgets/listview.h
index 81d705b1..2eda9d43 100644
--- a/include/widgets/listview.h
+++ b/include/widgets/listview.h
@@ -77,7 +77,7 @@ typedef void ( *listview_mouse_activated_cb )( listview *, gboolean, void * );
*
* @returns a new listview
*/
-listview *listview_create ( const char *name, listview_update_callback cb, void *udata, unsigned int eh, gboolean reverse );
+listview *listview_create ( widget *parent, const char *name, listview_update_callback cb, void *udata, unsigned int eh, gboolean reverse );
/**
* @param lv The listview handle
diff --git a/include/widgets/scrollbar.h b/include/widgets/scrollbar.h
index 6c7af7c8..0339abf2 100644
--- a/include/widgets/scrollbar.h
+++ b/include/widgets/scrollbar.h
@@ -50,13 +50,14 @@ typedef struct _scrollbar
} scrollbar;
/**
+ * @parem parent The parent widget.
* @param name The name of the widget.
*
* Create a new scrollbar
*
* @returns the scrollbar object.
*/
-scrollbar *scrollbar_create ( const char *name );
+scrollbar *scrollbar_create ( widget *parent, const char *name );
/**
* @param sb scrollbar object
diff --git a/include/widgets/textbox.h b/include/widgets/textbox.h
index 3ea8074b..c238fb5e 100644
--- a/include/widgets/textbox.h
+++ b/include/widgets/textbox.h
@@ -127,7 +127,7 @@ typedef enum
* free with #widget_free
* @returns a new #textbox
*/
-textbox* textbox_create ( WidgetType type, const char *name, TextboxFlags flags,
+textbox* textbox_create ( widget *parent, WidgetType type, const char *name, TextboxFlags flags,
TextBoxFontType tbft, const char *text, double xalign, double yalign );
/**
* @param tb Handle to the textbox
diff --git a/include/widgets/widget-internal.h b/include/widgets/widget-internal.h
index 8ae1f823..e32c8766 100644
--- a/include/widgets/widget-internal.h
+++ b/include/widgets/widget-internal.h
@@ -97,14 +97,15 @@ struct _widget
};
/**
* @param widget The widget to initialize.
* @param type The type of the widget.
* @param name The name of the widget.
*
* Initializes the widget structure.
*
*/
-void widget_init ( widget *widget, WidgetType type, const char *name );
+void widget_init ( widget *wid, widget *parent, WidgetType type, const char *name );
/**
* @param widget The widget handle.
@@ -97,14 +97,15 @@ struct _widget
};
/**
- * @param widget The widget to initialize.
+ * @param wid The widget to initialize.
+ * @param parent The widget's parent.
* @param type The type of the widget.
* @param name The name of the widget.